Search
===================

Search methods for Trees.

.. list-table:: Tree Search Methods
   :widths: 30 40 40
   :header-rows: 1

   * - Search by
     - One node
     - One or more nodes
   * - General method
     - `find`
     - `findall`
   * - Node name
     - `find_name`, `find_children`
     - `find_names`
   * - Node path
     - `find_path`, `find_full_path`
     - `find_paths`
   * - Node attributes
     - `find_attr`
     - `find_attrs`

.. automodule:: bigtree.tree.search
   :members:
   :show-inheritance:
